@@ -164,7 +164,7 @@ class MatriceDeployServer:
                 logging.error("Error during signal-triggered shutdown: %s", str(exc))
             finally:
                 os._exit(0)
-        
+
         def atexit_handler():
             logging.info("Process exiting, ensuring graceful shutdown...")
             try:
@@ -172,14 +172,14 @@ class MatriceDeployServer:
                     self.stop_server()
             except Exception as exc:
                 logging.error("Error during atexit shutdown: %s", str(exc))
-        
+
         # Register signal handlers for graceful shutdown
         signal.signal(signal.SIGTERM, signal_handler)
         signal.signal(signal.SIGINT, signal_handler)
-        
+
         # Register atexit handler as a final safety net
         atexit.register(atexit_handler)
-        
+
         logging.info("Shutdown handlers registered successfully")
 
     def _validate_init_parameters(self, load_model, predict, action_id, external_port):
@@ -234,7 +234,7 @@ class MatriceDeployServer:
                 self.action_tracker, self.inference_interface, self.external_port
             )
             self.utils.update_deployment_address()
-            # self.utils.run_background_checkers()
+            self.utils.run_background_checkers()
             self.action_tracker.update_status(
                 "MDL_DPY_STR",
                 "SUCCESS",
@@ -336,101 +336,70 @@ class MatriceDeployServer:
             num_producers=int(self.action_details.get("numProducers", 1)),
             app_name=self.app_name,
             app_version=self.app_version,
-            inference_pipeline_id=self.inference_pipeline_id
+            inference_pipeline_id=self.inference_pipeline_id,
         )
 
-        # Start stream manager in background thread since it's async
-        def start_stream_manager():
-            """Start the async stream manager in a new event loop."""
+        def run_stream_manager_in_thread():
+            """Run stream manager in a separate thread with its own event loop."""
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
 
-            async def start_and_run_until_shutdown():
+            async def run_stream_manager_until_shutdown():
                 try:
-                    # Add small delay to ensure server components are fully initialized
-                    await asyncio.sleep(2.0)
+                    # Check if shutdown was already signaled before starting
+                    if self._shutdown_event.is_set():
+                        logging.warning("Shutdown already signaled, not starting stream manager")
+                        return
                     
                     await self.stream_manager.start()
                     logging.info("Stream manager started successfully")
-                    
-                    # Wait for shutdown signal instead of waiting forever
+
+                    # Wait until shutdown event (poll periodically since threading.Event isn't async)
                     while not self._shutdown_event.is_set():
-                        try:
-                            await asyncio.sleep(1.0)  # Check shutdown every second
-                        except asyncio.CancelledError:
-                            break
+                        await asyncio.sleep(0.1)
                     
-                    logging.info("Shutdown signal received, stopping stream manager")
-                    await self.stream_manager.stop()
-                    logging.info("Stream manager stopped successfully")
-                    
-                except Exception as exc:
-                    logging.error("Error in stream manager: %s", str(exc))
-                    # Update status to indicate error
-                    try:
-                        self.action_tracker.update_status(
-                            "ERROR",
-                            "ERROR", 
-                            f"Stream manager error: {str(exc)}"
-                        )
-                    except Exception:
-                        pass  # Don't fail if status update fails
+                    logging.info("Shutdown event received, stream manager will stop")
+                except asyncio.CancelledError:
+                    logging.info("Stream manager task was cancelled")
                     raise
+                except Exception as exc:
+                    logging.error("Stream manager crashed: %s", exc)
+                    raise
+                finally:
+                    if self.stream_manager:
+                        try:
+                            await self.stream_manager.stop()
+                        except Exception as exc:
+                            logging.error("Error while stopping stream manager: %s", exc)
+                        else:
+                            logging.info("Stream manager stopped successfully")
 
             try:
-                loop = asyncio.new_event_loop()
-                asyncio.set_event_loop(loop)
-                
-                # Ensure loop is properly set up
-                logging.debug("Stream manager event loop created and set")
-                
+                loop.run_until_complete(run_stream_manager_until_shutdown())
+            finally:
                 try:
-                    loop.run_until_complete(start_and_run_until_shutdown())
-                    
-                    # After main coroutine completes, ensure all tasks are properly cleaned up
+                    # Cancel any straggler tasks
                     pending = asyncio.all_tasks(loop)
-                    if pending:
-                        logging.info("Cancelling %d pending tasks in stream manager loop", len(pending))
-                        for task in pending:
-                            if not task.done():
-                                task.cancel()
-                        
-                        # Wait for all tasks to complete with timeout
-                        try:
-                            loop.run_until_complete(
-                                asyncio.wait_for(
-                                    asyncio.gather(*pending, return_exceptions=True),
-                                    timeout=10.0
-                                )
-                            )
-                            logging.info("All pending tasks cancelled successfully")
-                        except asyncio.TimeoutError:
-                            logging.warning("Some tasks did not cancel within timeout")
-                        except Exception as exc:
-                            logging.warning("Error during task cancellation: %s", str(exc))
-                    
-                    # Give a brief moment for final cleanup
-                    time.sleep(0.1)
-                    
+                    for task in pending:
+                        task.cancel()
+                    loop.run_until_complete(asyncio.gather(*pending, return_exceptions=True))
+                except Exception as exc:
+                    logging.warning("Error while cancelling pending tasks: %s", exc)
                 finally:
-                    try:
-                        # Close the event loop only after everything is cleaned up
-                        if not loop.is_closed():
-                            loop.close()
-                            logging.info("Stream event loop closed successfully")
-                    except Exception as exc:
-                        logging.warning("Error closing stream event loop: %s", str(exc))
-                        
-            except Exception as exc:
-                logging.error("Failed to start stream manager: %s", str(exc))
-                raise
-
+                    loop.close()
+                    logging.info("Stream manager loop closed")
+        
         try:
+            # Start the stream manager in a separate thread
             self._stream_manager_thread = threading.Thread(
-                target=start_stream_manager, daemon=False, name="StreamManager"
+                target=run_stream_manager_in_thread,
+                name="StreamManagerThread",
+                daemon=True
             )
             self._stream_manager_thread.start()
             logging.info("Stream manager thread started successfully")
         except Exception as exc:
-            logging.error("Failed to start stream thread: %s", str(exc))
+            logging.error("Failed to start stream manager thread: %s", str(exc))
             raise
 
     def _start_proxy_interface(self):
@@ -463,31 +432,32 @@ class MatriceDeployServer:
         """Stop the server and related components."""
         try:
             logging.info("Initiating server shutdown...")
-            
+
             # Signal shutdown to all components
             self._shutdown_event.set()
             
-            # Wait for stream manager thread to finish if it exists
+            # Wait for stream manager thread to finish
             if self._stream_manager_thread and self._stream_manager_thread.is_alive():
-                logging.info("Waiting for stream manager thread to finish...")
-                self._stream_manager_thread.join(timeout=30.0)  # 30 second timeout
-                if self._stream_manager_thread.is_alive():
-                    logging.warning("Stream manager thread did not finish within timeout")
-                else:
-                    logging.info("Stream manager thread finished successfully")
-            
+                logging.info("Waiting for stream manager thread to stop...")
+                try:
+                    self._stream_manager_thread.join(timeout=10.0)
+                    if self._stream_manager_thread.is_alive():
+                        logging.warning("Stream manager thread did not stop within timeout")
+                    else:
+                        logging.info("Stream manager thread stopped successfully")
+                except Exception as exc:
+                    logging.error("Error waiting for stream manager thread: %s", str(exc))
+
             # Stop proxy interface
             if self.proxy_interface:
                 try:
-                    # Add proxy interface stop method if available
-                    if hasattr(self.proxy_interface, 'stop'):
-                        self.proxy_interface.stop()
+                    self.proxy_interface.stop()
                     logging.info("Proxy interface stopped")
                 except Exception as exc:
                     logging.error("Error stopping proxy interface: %s", str(exc))
-            
+
             logging.info("Server shutdown completed")
-            
+
         except Exception as exc:
             logging.error("Error during server shutdown: %s", str(exc))
             raise
